"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.consoleLog = consoleLog;
exports.displayParams = displayParams;
exports.istartedInVscode = istartedInVscode;
//#endregion
const level_1 = require("./level");
//#region @backend
const lib_1 = require("tnp-core/lib");
const json5 = require("json5");
const stringify = require("json-stringify-safe");
const lib_2 = require("tnp-core/lib");
//#endregion
function consoleLog(data, level) {
    //#region @backend
    if (level === level_1.Level.INFO)
        lib_2.Helpers.info(data);
    else if (level === level_1.Level.ERROR)
        lib_2.Helpers.error(data);
    else if (level === level_1.Level.WARN)
        lib_2.Helpers.warn(data);
    else if (level === level_1.Level.SUCCESS)
        lib_2.Helpers.success(data);
    else if (level === level_1.Level.TASK_STARTED)
        lib_2.Helpers.taskStarted(data);
    else if (level === level_1.Level.TASK_DONE)
        lib_2.Helpers.taskDone(data);
    else
        lib_2.Helpers.log(data);
    //#endregion
}
function displayParams(params = [], level) {
    //#region @backend
    params.forEach(param => {
        if (typeof param === 'object') {
            handleObjectData(param, level);
        }
        else if (isObjectAfterStringify(param)) {
            handleObjectData(json5.parse(param), level);
        }
        else {
            consoleLog(param, level);
        }
    });
    //#endregion
}
function replace(out, match, char, color) {
    //#region @backend
    let m = out.match(match);
    let outer = out;
    if (m)
        m.forEach(p => {
            const rep = p
                .slice(1)
                .replace(char, '');
            outer = outer.replace(`"${rep}":`, `"${color.call(null, rep)}":`);
        });
    return outer;
    //#endregion
}
function handleObjectData(param, level) {
    //#region @backend
    if (istartedInVscode()) {
        consoleLog(param, level);
        return;
    }
    let out = stringify(param, null, 4);
    out = replace(out, /\".*"\:\ \"/g, /\"\: "/, lib_1.chalk.green);
    out = replace(out, /\".*"\:\ \{/g, /\"\: \{/, lib_1.chalk.yellow);
    out = replace(out, /\".*"\:\ \[/g, /\"\: \[/, lib_1.chalk.red);
    out = replace(out, /\".*"\:\ true/g, /\"\: true/, lib_1.chalk.blue);
    out = replace(out, /\".*"\:\ false/g, /\"\: false/, lib_1.chalk.blue);
    out = replace(out, /\".*"\:\ (\-|[0-9])/g, /\"\: (\-|[0-9])/, lib_1.chalk.magenta);
    out = out.replace(/\"/g, lib_1.chalk.dim('"'))
        .replace(/\{/g, lib_1.chalk.dim('{'))
        .replace(/\}/g, lib_1.chalk.dim('}'))
        .replace(/\}/g, lib_1.chalk.dim('}'));
    if (process.stdout.columns && process.stdout.columns > 0) {
        out = out.split('\n').map(line => {
            return (line.length < process.stdout.columns ?
                line :
                line.slice(0, process.stdout.columns - 6) + lib_1.chalk.dim('...'));
        }).join('\n');
    }
    consoleLog(out, level);
    //#endregion
}
function istartedInVscode() {
    //#region @backend
    let args = process.execArgv;
    if (args) {
        return args.some((arg) => /^--debug=?/.test(arg) ||
            /^--debug-brk=?/.test(arg) ||
            /^--inspect=?/.test(arg) ||
            /^--inspect-brk=?/.test(arg));
    }
    return false;
    //#endregion
}
function isObjectAfterStringify(s) {
    //#region @backend
    try {
        json5.parse(s);
        return true;
    }
    catch (error) {
        return false;
    }
    //#endregion
}
//# sourceMappingURL=backend-logging.js.map