"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.Log = void 0;
const logger_1 = require("./logger");
const level_1 = require("./level");
const lib_1 = require("tnp-core/lib");
//#endregion
//#region @backend
const randomcolor = require("randomcolor");
//#endregion
class Log {
    //#region singleton
    constructor() { }
    // @ts-ignore
    static get instance() {
        // @ts-ignore
        if (!Log['_instance']) {
            // @ts-ignore
            Log['_instance'] = new Log();
        }
        // @ts-ignore
        return Log['_instance'];
    }
    //#endregion
    static Logger = logger_1.Logger;
    static create(name, ...level) {
        return Log.instance.create(name, ...level);
    }
    static consolelogfn = {};
    static disableLogs(level = level_1.Level.__NOTHING) {
        //#region @backend
        // if (Helpers.isNode && (level === Level.__NOTHING)) {
        //   if (!this.consolelogfn[PROCESS_STDOUT_WRITE]) {
        //     this.consolelogfn[PROCESS_STDOUT_WRITE] = process.stdout.write; // TOOD not working
        //   }
        //   process.stdout.write = (() => { }) as any;
        // }
        //#endregion
        level_1.LevelOrder.reverse().find(a => {
            // @ts-ignore
            if (!this.consolelogfn[a]) {
                // @ts-ignore
                this.consolelogfn[a] = console[a];
            }
            // @ts-ignore
            console[a] = () => { };
            if (a === level_1.LevelKey[level]) {
                return true;
            }
            return false;
        });
    }
    static enableLogs() {
        //#region @backend
        // if (Helpers.isNode) {
        //   process.stdout.write = this.consolelogfn[PROCESS_STDOUT_WRITE];
        // }
        //#endregion
        level_1.LevelOrder.forEach(a => {
            // @ts-ignore
            console[a] = this.consolelogfn[a];
        });
    }
    _logOnly = false;
    _logModules = false;
    isDevelopmentMode = true;
    modeIsSet = false;
    fixedWidth = 0;
    instances = {};
    levels = [];
    modules = [];
    //#region public api
    setProductionMode() {
        if (this.modeIsSet) {
            this.modeIsSet = false;
            throw '[ng2-logger] Production mode is already set';
        }
        else {
            this.modeIsSet = true;
            setTimeout(() => {
                if (this.modeIsSet && console !== void 0 && console.clear !== void 0) {
                    console.clear();
                    console.log = () => { };
                    console.error = () => { };
                    console.warn = () => { };
                    console.info = () => { };
                }
            });
            this.isDevelopmentMode = false;
        }
    }
    onlyModules(...modules) {
        if (this._logModules) {
            throw '[ng2-logger] You should use funcion onlyModules only once';
        }
        if (!this._logModules) {
            this._logModules = true;
        }
        if (modules.length === 0)
            return;
        this.modules = modules;
        // console.log('only log this', Log.modules)
        this.muteAllOtherModules();
    }
    onlyLevel(...level) {
        if (this._logOnly) {
            throw '[ng2-logger] You should use funcion onlyLevel only once';
        }
        if (!this._logOnly) {
            this._logOnly = true;
        }
        this.levels = Array.isArray(level) ? level : [level];
        for (const logName in this.instances) {
            if (this.instances.hasOwnProperty(logName)) {
                const element = this.instances[logName];
                element['allowed'] = this.levels;
            }
        }
    }
    //#endregion
    create(name, ...level) {
        let i;
        if (Array.isArray(this.levels) && this.levels.length > 0) {
            level = this.levels;
        }
        if (this.instances[name] === void 0) {
            i = new (Log.Logger)(name, getRandomColor(), this.isDevelopmentMode, level, this.isMutedModule(name), this.levels.length > 0 ? this.fixedWidth : void 0);
            this.instances[name] = i;
        }
        else {
            i = this.instances[name];
        }
        return i;
    }
    isMutedModule(moduleName) {
        if (this.modules.length == 0)
            return false;
        if (!lib_1.Helpers.contain(this.modules, moduleName))
            return true;
        return false;
    }
    muteAllOtherModules() {
        for (var moduleName in this.instances) {
            if (!lib_1.Helpers.contain(this.modules, moduleName))
                this.instances[moduleName].mute();
        }
    }
}
exports.Log = Log;
function getRandomColor() {
    //#region @backend
    if (lib_1.Helpers.isNode) {
        return randomcolor({ luminosity: 'light', count: 10 });
    }
    //#endregion
    let letters = '012345'.split('');
    let color = '#';
    color += letters[Math.round(Math.random() * 5)];
    letters = '0123456789ABCDEF'.split('');
    for (let i = 0; i < 5; i++) {
        color += letters[Math.round(Math.random() * 15)];
    }
    if (color === void 0) {
        return getRandomColor();
    }
    ;
    return color;
}
//# sourceMappingURL=log.js.map